| Safe Haskell | None |
|---|
Hbro.Types
- type K = KT IO
- newtype KT m a = KT (ReaderT Environment m a)
- data Environment = Environment {}
- data CliOptions = CliOptions {
- mURI :: Maybe String
- mVanilla :: Bool
- mRecompile :: Bool
- mDenyReconf :: Bool
- mForceReconf :: Bool
- mDyreDebug :: Bool
- mMasterBinary :: Maybe String
- data Config = Config {
- mSocketDir :: RefDirs -> FilePath
- mUIFile :: RefDirs -> FilePath
- mHomePage :: String
- mWebSettings :: [AttrOp WebSettings]
- mCommands :: CommandsList
- mHooks :: Hooks
- type Config' = Either String Config
- data Hooks = Hooks {
- mBackForward :: URI -> WebPolicyDecision -> K ()
- mDownload :: URI -> String -> Int -> K ()
- mFormResubmitted :: URI -> WebPolicyDecision -> K ()
- mFormSubmitted :: URI -> WebPolicyDecision -> K ()
- mKeyPressed :: String -> K ()
- mLinkClicked :: Button -> URI -> WebPolicyDecision -> K ()
- mLoadFinished :: K ()
- mMIMEDisposition :: URI -> String -> WebPolicyDecision -> K ()
- mNewWindow :: URI -> K ()
- mOtherNavigation :: URI -> WebPolicyDecision -> K ()
- mReload :: URI -> WebPolicyDecision -> K ()
- mStartUp :: K ()
- mTitleChanged :: String -> K ()
- data GUI = GUI {}
- data PromptBar = PromptBar {}
- data NotificationBar = NotificationBar {}
- data RefDirs = RefDirs {}
- type PortableFilePath = RefDirs -> FilePath
- type KeysList = [(String, K ())]
- type KeysMap = Map String (K ())
- type KeyEventCallback = [Modifier] -> String -> IO Bool
- type CommandsList = [(String, [String] -> K String)]
- type CommandsMap = Map String ([String] -> K String)
- data Button
- data CaseSensitivity
- data Direction
- data Wrap
Documentation
Constructors
| KT (ReaderT Environment m a) |
data Environment Source
The whole set of parameters, elements and states of the application
Constructors
| Environment | |
Instances
| Monad m => MonadReader Environment (KT m) |
data CliOptions Source
Set of commandline options
Constructors
| CliOptions | |
Fields
| |
Instances
Custom parameters provided by the user
Constructors
| Config | |
Fields
| |
Set of functions to be triggered when some events occur
Constructors
| Hooks | |
Fields
| |
Graphical elements
Constructors
| GUI | |
Fields
| |
Prompt-bar elements
data NotificationBar Source
Notification-bar elements
Set of reference directories, typically used to build FilePath-s
Constructors
| RefDirs | |
Fields
| |
type PortableFilePath = RefDirs -> FilePathSource
type KeysList = [(String, K ())]Source
List of bound keys. All callbacks are fed with the Environment instance.
data CaseSensitivity Source
Constructors
| CaseSensitive | |
| CaseInsensitive |