| Safe Haskell | None |
|---|
Hbro.Types
- data Browser = Browser {}
- data CliOptions = CliOptions {}
- data Configuration = Configuration {}
- data GUI = GUI {}
- type KeysList = [(([Modifier], String), Browser -> IO ())]
Documentation
Constructors
| Browser | |
Fields
| |
data Configuration Source
Constructors
| Configuration | |
Fields
| |
Constructors
| GUI | |
Fields
| |
type KeysList = [(([Modifier], String), Browser -> IO ())]Source
List of bound keys All callbacks are fed with the Browser instance Note 1 : for modifiers, lists are used for convenience purposes, but are transformed into sets in hbro's internal machinery, so that order and repetition don't matter Note 2 : for printable characters accessed via the shift modifier, you do have to include Shift in modifiers list